# Ansible Repository by PARAGON

This repository is a collection of playbooks, roles, plugins and inventories for
multiple clients that PARAGON supports. It is build such that multiple clients 
could be installed on a single control host. However, by default the setup
script installs the framework for an individual custumer so that those can use
it for themselves too.

## Installation

```
# Install Ansible: http://docs.ansible.com/ansible/intro_installation.html
sudo apt-get install software-properties-common
sudo apt-add-repository ppa:ansible/ansible
sudo apt-get update
sudo apt-get install ansible

# Create your Ansible home directory (e.g. /opt/ansible)
mkdir /opt/ansible

# Checkout the main repository
git clone git@gitlab.paragon-es.de:ansible-playbooks/general.git /opt/ansible
cd /opt/ansible

# Setup or update
./setup_local.sh [COMPANY]

# Optional additional system components
sudo apt-get install python-setuptools
sudo easy_install -U pip
sudo pip install requests
```

## Configuration

The above installation configures Ansible such that everything is good to go
and you can call the ```setup_local.sh``` script again at any time to grab updates
or restore settings if something got broken.

However, there might be additional settings that make the usage of Ansible more
convenient and we're describing them here with detailed descriptions.

### Ansible configuration

You'll find a file ```.ansible.cfg```in your home directory after the setup from
above and there are certain additional settings that could be usefull:

#### Working with a vault for automatic sudo password input

When using Ansible with this repository you'll get asked for your remove sudo
password every single time. If you want to avoid that, you can store that password
in a vault so that Ansible grabs it from there automatically.

**Warning:** Only use that if you have full control over the Ansible control host
because otherwise someone else could get access to your whole server farm.

1. Create your vault password file

   Create a file named ```~/.ansible/vault.pwd``` and edit that file so that it
   contains your local password for your Ansible vault.
2. Create you vault file

   Use the command ```ansible-vault create ~/.ansible/secrets``` and include
   one line ```ansible_sudo_pass: 'YOURSUDOPASS'```. This is using your default
   editor for the console but you can configure that like ```export $EDITOR=nano```
   to use the nano editor as an example. When saving the file, ansible-vault
   will encrypt that file with your vault password contained in the vault.pwd file.
3. (Optional) Edit your vault file later on

   If you later want to edit your secrets, use ```ansible-vault create ~/.ansible/secrets```

### Creating shortcuts for the scripts

All the scripts in this repository are written in a way that they can be called
from everywhere, you don't have to chdir into the repository directory first.

For better convenience, we recommend to create shortcuts in a directory which is
part of your PATH environment variable. Examples:

```
cd /usr/local/bin
sudo ln -s /opt/ansible/directory/ansible.sh a
sudo ln -s /opt/ansible/directory/ansible-playbook.sh apb
sudo ln -s /opt/ansible/directory/sanity.sh asanity
```

### Preparing access to existing hosts

Ansible knows the hosts by name and the company specific naming convention should
be reflected on each local host that wants to use Ansible to manage them. You'll
find the hostnames in the file called ```inventory``` and you should make sure
that your local host knows them by name and their IP address. For this, add a new
line for each of those hosts into your ```/etc/hosts``` file starting with the
IP address followed by a space and the hostname from the inventory file.

Next, and this is the final piece before you can start using Ansible to access
your hosts, make sure that you can access your hosts via SSH. This repository
is built with security at the forefront and therefore access is only available
through a PKI infrastructure. To configure your system for easy access, you
should have a file ```$HOME/.ssh/config``` with some content similar to the
following:

```
ForwardAgent yes

Host *
  User [YOUR REMOTE USERNAME]
  IdentityFile ~/.ssh/id_rsa
```

The above setting applies to all hosts and the definition of the remote user name
is only neccessary if that remote username is different from your local one. Please
note that you should define the same username also in ```$HOME/.ansible.cfg```

## Where to go next?

The best place to continue reading is by heading over to the [Wiki](https://gitlab.paragon-es.de/ansible-playbooks/general/wikis/home)
