#!/bin/bash

if [ -d ~/.ansible ]
  then
    SECRETS="$( cd ~/.ansible && pwd )/secrets"
fi
cd $( cd $(dirname $(readlink -f $0)) ; pwd )

if [ $1 == "local" ]
  then
    CUSTOM_DIR=false
    INVENTORY=./local.inventory
    shift
  else
    if [ -f ./inventory/inventory ]
      then
        CUSTOM_DIR=./inventory
      else
        CUSTOM_DIR=./inventory/$ANSIBLE_COMPANY
    fi
    INVENTORY=$CUSTOM_DIR/inventory
fi

if [ "$1" == "" ]
  then
    echo "Usage"
    echo "ansible-playbook.sh PLAYBOOK ..."
    exit 101;
fi

if [ $1 == "custom" ]
  then
    shift
    PLAYBOOK_PREFIX=$CUSTOM_DIR/
  else
    PLAYBOOK_PREFIX=""
fi
PLAYBOOK=$PLAYBOOK_PREFIX$1.yml
shift

if [ ! -f $INVENTORY ]
  then
    echo "The inventory $INVENTORY does not exist!"
    exit 102;
fi

if [ ! -f $PLAYBOOK ]
  then
    echo "The playbook $PLAYBOOK does not exist!"
    exit 103;
fi

if [ $SECRETS ] && [ -f $SECRETS ]
  then
    ansible-playbook $PLAYBOOK -i $INVENTORY -e @$SECRETS "$@"
  else
    ansible-playbook $PLAYBOOK -i $INVENTORY --ask-sudo-pass "$@"
fi

if [ $CUSTOM_DIR != "false" ] && [ "$CUSTOM_DIR" != "$PLAYBOOK_PREFIX" ] && [ -f $CUSTOM_DIR/$PLAYBOOK ]
  then
    if [ $SECRETS ] && [ -f $SECRETS ]
      then
        ansible-playbook $CUSTOM_DIR/$PLAYBOOK -i $INVENTORY -e @$SECRETS "$@"
      else
        ansible-playbook $CUSTOM_DIR/$PLAYBOOK -i $INVENTORY --ask-sudo-pass "$@"
    fi
fi
